"""
Metrics handler module.

This module provides a class to handle all service metrics.
"""

from prometheus_client import CONTENT_TYPE_LATEST, generate_latest
from sanic import HTTPResponse

from ..errors.errors import Error
from ..errors.exception import VLException
from ..web.handlers import BaseHandler


class MetricsHandler(BaseHandler):
    """Metrics handler class."""

    async def get(self) -> HTTPResponse:
        """
        Get services statistics

        Resource is reachable at `/metrics` route.
        """
        if not hasattr(self.request.appCtx.serviceConfig, "metrics"):
            raise VLException(Error.ResourceIsDisabled, statusCode=403, isCriticalError=False)

        if not self.request.appCtx.serviceConfig.metrics.enabled:
            raise VLException(Error.ResourceIsDisabled, statusCode=403, isCriticalError=False)
        res = generate_latest(self.request.appCtx.metrics.registry)
        return HTTPResponse(body=res, headers={**self.respHeaders, "Content-Type": CONTENT_TYPE_LATEST}, status=200)
